@@ -1,4 +1,5 @@
 import os
+from english_heroku import heroku_words
 
 class Anagram(object):
     
@@ -15,11 +16,17 @@ class Anagram(object):
         self.json = {"anagram": [], "non-anagram": []}
         self.path = os.getcwd()
     
-    def init_app(self):
+    def init_app(self, heroku=False):
         
-        with open(self.path + "\\english.txt", "r") as r:
-            words = r.read().replace("\n", ",").split(",")
+        if heroku:
             
+            self.words = heroku_words.split(" ")
+            
+        else:
+            
+            with open(self.path + "\\english.txt", "r") as r:
+                words = r.read().replace("\n", ",").split(",")
+
         self.words = words
         
     
